<?php
/**
 * Hitoma Theme Customizer
 *
 * @package Hitoma
 */

//======================================================================
//
// カスタマイザー
//
//======================================================================
/**
 * カスタマイザーに項目追加
 *
 * @param $wp_customize
 */
if ( ! function_exists( 'hitoma_customize_register' ) ):
    function hitoma_customize_register( $wp_customize ) {

	    /**
	     * READ ME
	     */
	    class Hitoma_theme_Read_Me extends WP_Customize_Control {
            public function render_content() {
                ?>
                <div>
                    <p><?php esc_html_e( 'Thank you for using the Hitoma theme.', THEME_NAME ); ?></p>
                    <h3><?php esc_html_e( 'Documentation', THEME_NAME ); ?></h3>
                    <p><?php esc_html_e( 'For instructions on theme configuration, please see the documentation.', THEME_NAME ); ?></p>
                    <p><a href="<?php echo esc_url( 'https://soooooko.com/wordpress-themes/hitoma/', THEME_NAME ); ?>" target="_blank" rel="noopener noreferrer"><?php esc_html_e( 'Theme Documentation', THEME_NAME ); ?></a></p>
                </div>
                <?php
            }
        }

        $wp_customize->add_section( 'hitoma_theme_read_me', array(
            'title'    => esc_html__( 'READ ME', THEME_NAME ),
            'priority' => 1,
        ) );

	    $wp_customize->add_setting( 'hitoma_theme_read_me_text', array(
        ) );

        $wp_customize->add_control( new Hitoma_theme_Read_Me( $wp_customize, 'hitoma_theme_read_me_text', array(
            'section'  => 'hitoma_theme_read_me',
            'priority' => 1,
        ) ) );

        /**
         * 基本情報セクション
         */
        $wp_customize->add_section( 'title_tagline', array(
            'title'       => esc_html__( 'Basic information', THEME_NAME ),
            'description' => esc_html__( 'If you input an empty, you can hide unnecessary items.', THEME_NAME ),
        ) );

        // 基本情報セクション setting
        $wp_customize->add_setting( 'hitoma-theme_options-logo_image', array(
            'default'           => DEFAULT_LOGO_IMAGE_URL,
            'sanitize_callback' => 'hitoma_sanitize_upload_image',
        ) );

	    $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

        $wp_customize->add_setting( 'hitoma-theme_options-title_font_size', array(
            'default'           => DEFAULT_TITLE_FONT_SIZE,
            'transport'         => 'postMessage',
            'sanitize_callback' => 'hitoma_sanitize_number',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-logo_margin_right', array(
            'default'           => DEFAULT_LOGO_MARGIN_RIGHT,
            'transport'         => 'postMessage',
            'sanitize_callback' => 'hitoma_sanitize_number',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-title_margin_top', array(
            'default'           => DEFAULT_TITLE_MARGIN_TOP,
            'transport'         => 'postMessage',
            'sanitize_callback' => 'hitoma_sanitize_number',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-main_image', array(
            'default'           => DEFAULT_MAIN_IMAGE_URL,
            'sanitize_callback' => 'hitoma_sanitize_upload_image',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-catch_phrase', array(
            'default'           => DEFAULT_CATCH_PHRASE,
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-catch_phrase_color', array(
            'default'           => DEFAULT_CATCH_PHRASE_COLOR,
            'capability'        => 'edit_theme_options',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-background_color', array(
            'default'           => DEFAULT_BACKGROUND_COLOR,
            'capability'        => 'edit_theme_options',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-contents_background_color', array(
            'default'           => DEFAULT_CONTENTS_BACKGROUND_COLOR,
            'capability'        => 'edit_theme_options',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-meta_description', array(
            'default'           => DEFAULT_META_DESCRIPTION,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        // 基本情報セクション control
        $wp_customize->add_control( 'blogdescription', array(
            'label'             => esc_html__( 'Description of title', THEME_NAME ),
            'description'       => esc_html__( 'This is a text which is shown on browser\'s title bar. (ex, Hitoma | Just another Wordpress site)', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'blogdescription',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( new WP_Customize_Image_Control(
            $wp_customize,
            'hitoma-theme_options-logo_image',
            array(
                'label'         => esc_html__( 'Logo image', THEME_NAME ),
                'section'       => 'title_tagline',
                'settings'      => 'hitoma-theme_options-logo_image',
                'priority'      => 0,
            )
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-title_font_size', array(
            'label'             => esc_html__( 'Title font size', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'hitoma-theme_options-title_font_size',
            'type'              => 'number',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-logo_margin_right', array(
            'label'             => esc_html__( 'Margin of the logo image\'s right space', THEME_NAME ),
            'description'       => esc_html__( 'When you expand the browser window, a logo image and title are lined up side by side. In the state you can adjust the right margin of logo.', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'hitoma-theme_options-logo_margin_right',
            'type'              => 'number',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-title_margin_top', array(
            'label'             => esc_html__( 'Adjusting a title\'s margin top', THEME_NAME ),
            'description'       => esc_html__( 'When you expand the browser window, a logo image and title are lined up side by side. In the state you can adjust the position of title.', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'hitoma-theme_options-title_margin_top',
            'type'              => 'number',
        ) );

        $wp_customize->add_control( new WP_Customize_Image_Control(
            $wp_customize,
            'hitoma-theme_options-main_image',
            array(
                'label'         => esc_html__( 'Main image', THEME_NAME ),
                'description'   => esc_html__( 'Use an image with width of 920px or more.', THEME_NAME ),
                'section'       => 'title_tagline',
                'settings'      => 'hitoma-theme_options-main_image',
            )
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-catch_phrase', array(
            'label'             => esc_html__( 'Catch phrase', THEME_NAME ),
            'description'       => esc_html__( 'It is shown above the main image.', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'hitoma-theme_options-catch_phrase',
            'type'              => 'text',
            'priority'          => 10,
        ) );

        $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'hitoma-theme_options-catch_phrase_color',
            array(
                'label'         => esc_html__( 'Catch phrase color', THEME_NAME ),
                'section'       => 'title_tagline',
                'settings'      => 'hitoma-theme_options-catch_phrase_color',
            )
        ) );

        $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'hitoma-theme_options-background_color',
            array(
                'label'         => esc_html__( 'Background color', THEME_NAME ),
                'section'       => 'title_tagline',
                'settings'      => 'hitoma-theme_options-background_color',
            )
        ) );

        $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'hitoma-theme_options-contents_background_color',
            array(
                'label'         => esc_html__( 'Background color of contents', THEME_NAME ),
                'section'       => 'title_tagline',
                'settings'      => 'hitoma-theme_options-contents_background_color',
            )
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-meta_description', array(
            'label'             => esc_html__( 'Meta description', THEME_NAME ),
            'description'       => esc_html__( 'It is the text which may be displayed under a title when we made Google searching. Because it is cut off even if too long and is displayed, please set it carefully.', THEME_NAME ),
            'section'           => 'title_tagline',
            'settings'          => 'hitoma-theme_options-meta_description',
            'type'              => 'textarea',
        ) );

        /**
         * TEL/FAX番号セクション
         */
        $wp_customize->add_section( 'contact_number_section', array(
            'title'             => esc_html__( 'TEL / FAX', THEME_NAME ),
            'description'       => esc_html__( 'You can show TEL number and FAX number. If you input an empty, you can hide unnecessary items.', THEME_NAME ),
        ) );

        // TEL/FAX番号セクション setting
        $wp_customize->add_setting( 'hitoma-theme_options-contact_number_tel', array(
            'default'           => DEFAULT_CONTACT_NUMBER_TEL,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-contact_number_fax', array(
            'default'           => DEFAULT_CONTACT_NUMBER_FAX,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-contact_number_text01', array(
            'default'           => DEFAULT_CONTACT_NUMBER_TEXT1,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-contact_number_text02', array(
            'default'           => DEFAULT_CONTACT_NUMBER_TEXT2,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        // TEL/FAX番号セクション control
        $wp_customize->add_control( 'hitoma-theme_options-contact_number_tel', array(
            'label'             => esc_html__( 'TEL number', THEME_NAME ),
            'section'           => 'contact_number_section',
            'settings'          => 'hitoma-theme_options-contact_number_tel',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-contact_number_fax', array(
            'label'             => esc_html__( 'FAX number', THEME_NAME ),
            'section'           => 'contact_number_section',
            'settings'          => 'hitoma-theme_options-contact_number_fax',
            'type'              => 'text',
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-contact_number_text01', array(
            'label'             => esc_html__( 'Text 1 under the number', THEME_NAME ),
            'section'           => 'contact_number_section',
            'settings'          => 'hitoma-theme_options-contact_number_text01',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-contact_number_text02', array(
            'label'             => esc_html__( 'Text 2 under the number', THEME_NAME ),
            'section'           => 'contact_number_section',
            'settings'          => 'hitoma-theme_options-contact_number_text02',
            'type'              => 'text',
        ) );

        /**
         * コンテンツページセクション
         */
        $wp_customize->add_section( 'contents_page_section', array(
            'title'             => esc_html__( 'Contents', THEME_NAME ),
            'description'       => esc_html__( 'Input a slug of page you can show the contents under the main image. If you input an empty, you can hide unnecessary items.', THEME_NAME ),
        ) );

        // コンテンツページセクション setting
        $wp_customize->add_setting( 'hitoma-theme_options-content1', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content2', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content3', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content4', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content5', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content6', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content7', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content8', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content9', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content10', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-content_privacy_policy', array(
            'default'           => DEFAULT_CONTENT_PRIVACY_POLICY_SLUG,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-main_image_margin_bottom', array(
            'default'           => DEFAULT_MAIN_IMAGE_MARGIN_BOTTOM,
            'sanitize_callback' => 'hitoma_sanitize_checkbox',
        ) );

        // コンテンツページセクション control
        $wp_customize->add_control( 'hitoma-theme_options-content1', array(
            'label'             => esc_html__( 'Slug of contents area 1', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content1',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content2', array(
            'label'             => esc_html__( 'Slug of contents area 2', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content2',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content3', array(
            'label'             => esc_html__( 'Slug of contents area 3', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content3',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content4', array(
            'label'             => esc_html__( 'Slug of contents area 4', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content4',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content5', array(
            'label'             => esc_html__( 'Slug of contents area 5', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content5',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content6', array(
            'label'             => esc_html__( 'Slug of contents area 6', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content6',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content7', array(
            'label'             => esc_html__( 'Slug of contents area 7', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content7',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content8', array(
            'label'             => esc_html__( 'Slug of contents area 8', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content8',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content9', array(
            'label'             => esc_html__( 'Slug of contents area 9', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content9',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content10', array(
            'label'             => esc_html__( 'Slug of contents area 10', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content10',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-content_privacy_policy', array(
            'label'             => esc_html__( 'Slug of privacy policy content', THEME_NAME ),
            'description'       => esc_html__( 'If you set, you can add a link to the privacy policy page at the bottom of the page.', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-content_privacy_policy',
            'type'              => 'text',
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-main_image_margin_bottom', array(
            'label'             => esc_html__( 'Delete gaps between main image and content', THEME_NAME ),
            'section'           => 'contents_page_section',
            'settings'          => 'hitoma-theme_options-main_image_margin_bottom',
            'type'              => 'checkbox',
        ) );

        /**
         * 地図セクション
         */
        $wp_customize->add_section( 'map_section', array(
            'title'             => esc_html__( 'Map', THEME_NAME ),
            'description'       => esc_html__( 'You can use this map area. Of course you can use it for another purpose. If you input an empty, you can hide unnecessary items.。', THEME_NAME ),
        ) );

        // 地図セクション setting
        $wp_customize->add_setting( 'hitoma-theme_options-map_original_map', array(
            'default'           => DEFAULT_ORIGINAL_MAP_IMAGE_URL,
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_setting( 'hitoma-theme_options-under_map_content', array(
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        // 地図セクション control
        $wp_customize->add_control( new WP_Customize_Image_Control(
            $wp_customize,
            'hitoma-theme_options-map_original_map',
            array(
                'label'         => esc_html__( 'Map image', THEME_NAME ),
                'description'   => esc_html__( 'Use an image with width of 920px or more. It is not displayed map content when you set this image.', THEME_NAME ),
                'section'       => 'map_section',
                'settings'      => 'hitoma-theme_options-map_original_map',
            )
        ) );

        $wp_customize->add_control( 'hitoma-theme_options-under_map_content', array(
            'label'             => esc_html__( 'Slug of map content', THEME_NAME ),
            'description'       => esc_html__( 'If you set a map image, it is not display this content.', THEME_NAME ),
            'section'           => 'map_section',
            'settings'          => 'hitoma-theme_options-under_map_content',
            'type'              => 'text',
        ) );
    }
endif;
add_action( 'customize_register', 'hitoma_customize_register', 20 );

/**
 * カスタマイザーでのプレビューを可能にする
 */
if ( ! function_exists( 'hitoma_customize_live_preview' ) ):
    function hitoma_customize_live_preview() {
        wp_enqueue_script(
            'hitoma-theme_customizer',
            get_template_directory_uri() . '/assets/js/theme-customizer.js',
            array( 'jquery', 'customize-preview' ),
            '1.0.0',
            true
        );
    }
endif;
add_action( 'customize_preview_init', 'hitoma_customize_live_preview' );

/**
 * カスタマイザーの不要な項目を削除
 *
 * @param $wp_customize
 */
if ( ! function_exists( 'hitoma_remove_customize_menu' ) ):
    function hitoma_remove_customize_menu( $wp_customize ) {
	    $wp_customize->get_panel( 'nav_menus' )->active_callback = '__return_false';
	    $wp_customize->remove_section( 'static_front_page' ); // ホームページ設定
    }
endif;
add_action( 'customize_register', 'hitoma_remove_customize_menu', 20 );

//-----------------------------------------------------
//
// サニタイズ
//
//-----------------------------------------------------
/**
 * 数値をサニタイズ
 *
 * @param $number
 * @param $setting
 *
 * @return int
 */
if ( ! function_exists( 'hitoma_sanitize_number' ) ):
    function hitoma_sanitize_number( $number ) {
        return absint( $number );
    }
endif;

/**
 * アップロード画像をサニタイズ
 *
 * @param $image
 *
 * @return string
 */
if ( ! function_exists( 'hitoma_sanitize_upload_image' ) ):
    function hitoma_sanitize_upload_image( $image ) {
        $file_type = wp_check_filetype( $image );

        if ( $file_type['ext'] && wp_ext2type( $file_type['ext'] ) === 'image' ) {
            return esc_url( $image );
        }

        return false;
    }
endif;

/**
 * チェックボックスをサニタイズ
 *
 * @param $checked
 *
 * @return bool
 */
if ( ! function_exists( 'hitoma_sanitize_checkbox' ) ):
    function hitoma_sanitize_checkbox( $checked ) {
        if ( isset( $checked ) && true == $checked ) {
            return true;
        }

        return false;
    }
endif;