<?php
/**
 * Hitoma init
 *
 * @package Hitoma
 */

//======================================================================
//
// 初期化
//
//======================================================================
/**
 * 多言語対応
 */
load_theme_textdomain( THEME_NAME, get_template_directory() . '/languages' );

/**
 * generatorを非表示にする
 */
remove_action( 'wp_head', 'wp_generator' );

/**
 * タイトル表示のセパレータを変更
 *
 * @param $sep
 *
 * @return string
 */
if ( ! function_exists( 'custom_title_separator' ) ):
	function custom_title_separator() {
		$sep = '|';

		return $sep;
	}
endif;

if ( ! function_exists( 'hitoma_theme_slug_setup' ) ):
	function hitoma_theme_slug_setup() {
		add_theme_support( 'title-tag' );
	}
endif;
add_filter( 'document_title_separator', 'custom_title_separator' );
add_action( 'after_setup_theme', 'hitoma_theme_slug_setup' );

/**
 * 管理バーの項目を削除
 *
 * @param $wp_admin_bar
 */
if ( ! function_exists( 'hitoma_remove_admin_bar_menus' ) ):
	function hitoma_remove_admin_bar_menus( $wp_admin_bar ) {
		$wp_admin_bar->remove_menu( 'comments' );     // コメント
		$wp_admin_bar->remove_menu( 'updates' );      // 更新
		$wp_admin_bar->remove_menu( 'new-content' );  // 新規
		$wp_admin_bar->remove_menu( 'new-post' );     // 新規 -> 投稿
		$wp_admin_bar->remove_menu( 'new-media' );    // 新規 -> メディア
		$wp_admin_bar->remove_menu( 'new-link' );     // 新規 -> リンク
		$wp_admin_bar->remove_menu( 'new-page' );     // 新規 -> 固定ページ
		$wp_admin_bar->remove_menu( 'new-user' );     // 新規 -> ユーザー
		$wp_admin_bar->remove_menu( 'my-account' );   // マイアカウント
		$wp_admin_bar->remove_menu( 'user-info' );    // マイアカウント -> プロフィール
		$wp_admin_bar->remove_menu( 'edit-profile' ); // マイアカウント -> プロフィール編集
		$wp_admin_bar->remove_menu( 'logout' );       // マイアカウント -> ログアウト
		$wp_admin_bar->remove_menu( 'search' );       // 検索
	}
endif;
add_action( 'admin_bar_menu', 'hitoma_remove_admin_bar_menus', 100 );

/**
 * 管理画面から余計なメニューを削除
 */
if ( ! function_exists( 'hitoma_remove_admin_menus' ) ):
	function hitoma_remove_admin_menus() {
		global $menu;
		unset( $menu[5] );  // 投稿
		unset( $menu[25] ); // コメント
	}
endif;
add_action( 'admin_menu', 'hitoma_remove_admin_menus' );

/**
 * 管理画面の設定から余計なサブメニューを削除
 */
if ( ! function_exists( 'hitoma_remove_admin_setting_menus' ) ):
	function hitoma_remove_admin_setting_menus() {
		remove_submenu_page( 'options-general.php', 'options-writing.php' );    // 投稿設定
		remove_submenu_page( 'options-general.php', 'options-discussion.php' ); // ディスカッション
		remove_submenu_page( 'options-general.php', 'options-permalink.php' );  // パーマリンク設定を非表示
	}
endif;
add_action( 'admin_menu', 'hitoma_remove_admin_setting_menus' );


/**
 * 投稿、固定ページ一覧にスラッグ表示
 *
 * 参考
 * https://hacknote.jp/archives/36831/
 * http://www.cms-seisaku.com/blog/wordpress/174
 */
if ( ! function_exists( 'hitoma_add_page_columns_slug' ) ):
	function hitoma_add_page_columns_slug( $columns ) {
		$columns['slug'] = 'スラッグ';

		return $columns;
	}
endif;

if ( ! function_exists( 'hitoma_add_page_column_slug_value' ) ):
	function hitoma_add_page_column_slug_value( $column_name, $post_id ) {
		if ( $column_name === 'slug' ) {
			$post = get_post( $post_id );
			$slug = $post->post_name;

			echo esc_attr( urldecode( $slug ) );
		}
	}
endif;
add_filter( 'manage_pages_columns', 'hitoma_add_page_columns_slug' );
add_action( 'manage_pages_custom_column', 'hitoma_add_page_column_slug_value', 10, 2 );

/**
 * 固定ページにスラッグを表示（Tiny MCE用）
 *
 * @param $hidden
 * @param $screen
 *
 * @return mixed
 */
if ( ! function_exists( 'hitoma_check_slug_metabox' ) ):
	function hitoma_check_slug_metabox( $hidden, $screen ) {
		$key = array_search( 'slugdiv', $hidden, true );
		unset( $hidden[ $key ] );

		return $hidden;
	}
endif;
add_filter( 'default_hidden_meta_boxes', 'hitoma_check_slug_metabox', 10, 2 );

//-----------------------------------------------------
// フィード
//-----------------------------------------------------
/**
 * フィードを無効化
 */
add_action( 'do_feed', 'do_feed');
add_action( 'do_feed_rdf', 'do_feed_rdf');
add_action( 'do_feed_rss', 'do_feed_rss');
add_action( 'do_feed_rss2', 'do_feed_rss2');
add_action( 'do_feed_atom', 'do_feed_atom');
add_action( 'do_feed_rss2_comments', 'do_feed_rss2_comments');
add_action( 'do_feed_atom_comments', 'do_feed_atom_comments');

// フィードのリンクを表示させないよう削除
remove_action( 'wp_head', 'feed_links');
remove_action( 'wp_head', 'feed_links_extra');

//-----------------------------------------------------
// スタイル・スクリプト
//-----------------------------------------------------
/**
 * 読み込むScriptsを登録する
 */
if ( ! function_exists( 'hitoma_register_scripts' ) ):
	function hitoma_register_scripts() {
		wp_enqueue_script(
			'app-script',
			get_template_directory_uri() . '/assets/js/app.js',
			array( 'jquery' ),
			'1.0.0',
			true
		);
	}
endif;
add_action( 'wp_enqueue_scripts', 'hitoma_register_scripts' );

/**
 * 読み込むCSSを登録する
 */
if ( ! function_exists( 'hitoma_register_stylesheet' ) ):
	function hitoma_register_stylesheet() {
		// 基本CSS
		wp_enqueue_style(
			'main-style',
			get_stylesheet_uri(),
			array(),
			'1.0.0',
			'all'
		);

		// これがないとinlineでcssを読み込んでくれない
		wp_enqueue_style(
			'custom-style',
			get_template_directory_uri() . '/assets/css/custom_script.css'
		);

		// customizerでの変更に対応させる
		$background_color          = get_theme_mod( 'hitoma-theme_options-background_color', DEFAULT_BACKGROUND_COLOR );
		$contents_background_color = get_theme_mod( 'hitoma-theme_options-contents_background_color', DEFAULT_CONTENTS_BACKGROUND_COLOR );
		$title_font_size           = get_theme_mod( 'hitoma-theme_options-title_font_size', DEFAULT_TITLE_FONT_SIZE ) . 'px';
		$title_margin_top          = get_theme_mod( 'hitoma-theme_options-title_margin_top', DEFAULT_TITLE_MARGIN_TOP ) . 'px';
		$logo_margin_right         = get_theme_mod( 'hitoma-theme_options-logo_margin_right', DEFAULT_LOGO_MARGIN_RIGHT ) . 'px';
		$catchphrase_color         = get_theme_mod( 'hitoma-theme_options-catch_phrase_color', DEFAULT_CATCH_PHRASE_COLOR );
		$main_image_margin_bottom  = get_theme_mod( 'hitoma-theme_options-main_image_margin_bottom', DEFAULT_MAIN_IMAGE_MARGIN_BOTTOM );

		$custom_css = "
	        body {
	            background: $background_color;
	        }
	        .contents-container {
	            background: $contents_background_color;
	        }
	        .title-logo {
	            margin-right: $logo_margin_right;
	        }
	        .title-text {
	            font-size: $title_font_size;
	            margin-top: $title_margin_top;
	        }
	        .main_image-catch_phrase {
	            color: $catchphrase_color;
	        }
	    ";

		if ( $main_image_margin_bottom ) {
			$custom_css .= "
				.main_image {
					margin-bottom: 0;
				}
			";
		}

		wp_add_inline_style( 'custom-style', $custom_css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'hitoma_register_stylesheet' );

